@@ -5,6 +5,6 @@ from lisa.server.libs.rulesengine import RulesEngine
 from lisa.server.libs.commands import Commands
 from lisa.server.libs.websocket import LisaClientFactory, WebSocketProtocol
 from lisa.server.libs.webserver import verifyCallback, Root
-from lisa.server.libs.server import Lisa, LisaFactory, ServerTLSContext, LisaFactorySingleton, taskman, scheduler, LisaProtocolSingleton, configuration, Initialize
+from lisa.server.libs.server import Lisa, LisaFactory, ServerTLSContext, LisaFactorySingleton, taskman, scheduler, LisaProtocolSingleton, Initialize
 #except ImportError:
 #    log.err(ImportError)
\ No newline at end of file
