@@ -5,11 +5,13 @@ from django.contrib.auth.decorators import login_required
 import requests, json
 from lisa.server.web.weblisa.utils import method_restricted_to
 
+from pkg_resources import get_distribution
+
 @method_restricted_to('GET')
 @login_required()
 def list(request):
     plugins = []
-    metareq = requests.get('https://raw.github.com/Seraf/LISA-Plugins/master/plugin_list.json')
+    metareq = requests.get('http://plugins.lisa-project.net/plugins.json')
     if(metareq.ok):
         for item in json.loads(metareq.text or metareq.content):
             for plugin in Plugin.objects(name=item['name']):
@@ -20,5 +22,6 @@ def list(request):
             #if os.path.exists(LISA_PATH + '/Plugins/' + item['name']):
             #    item['installed'] = True
             plugins.append(item)
-    return render_to_response('list.html', {'Plugins': plugins},
+    return render_to_response('list.html', {'Plugins': plugins,
+                                            'server_version': get_distribution('lisa-server').version},
                               context_instance=RequestContext(request))
